==> gsa-24.1.0.tar.gz: gsa-24.1.0/src/web/components/structure/header.jsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {useCallback} from 'react';

import {useNavigate} from 'react-router-dom';

import {AppHeader} from '@greenbone/opensight-ui-components-mantinev7';

import _ from 'gmp/locale';

import useUserIsLoggedIn from 'web/hooks/useUserIsLoggedIn';
import useUserName from 'web/hooks/useUserName';
import useGmp from 'web/hooks/useGmp';

import LogoutIcon from 'web/components/icon/logouticon';
import getLogo from 'web/components/structure/getLogo';
import MySettingsIcon from 'web/components/icon/mysettingsicon';
import LanguageSwitch from './languageswitch';
import SessionTimer from '../sessionTimer/SessionTimer';

const Header = () => {
  const gmp = useGmp();
  const username = useUserName();
  const loggedIn = useUserIsLoggedIn();
  const navigate = useNavigate();
  const logoComponent = getLogo(gmp.settings.vendorLabel);

  const handleSettingsClick = useCallback(
    event => {
      event.preventDefault();
      navigate('/usersettings');
    },
    [navigate],
  );

  const handleLogout = useCallback(
    event => {
      event.preventDefault();

      gmp.doLogout().then(() => {
        navigate('/login?type=logout');
      });
    },
    [gmp, navigate],
  );

  const menuPoints = [
    {
      to: handleSettingsClick,
      linkText: _('Settings'),
      icon: <MySettingsIcon />,
    },
    {
      to: handleLogout,
      linkText: _('Logout'),
      icon: <LogoutIcon />,
    },
  ];

  return (
    <AppHeader
      logo={logoComponent}
      languageSwitch={<LanguageSwitch />}
      menuPoints={menuPoints}
      isLoggedIn={loggedIn}
      sessionTimer={<SessionTimer />}
      username={username}
      logoLink="/dashboards"
      isThemeSwitchVisible={false}
    />
  );
};

export default Header;

==> gsa-24.3.0.tar.gz: gsa-24.3.0/src/web/components/structure/header.jsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {AppHeader} from '@greenbone/opensight-ui-components-mantinev7';
import {useCallback} from 'react';
import {useSelector} from 'react-redux';
import {useNavigate} from 'react-router-dom';
import LogoutIcon from 'web/components/icon/logouticon';
import MySettingsIcon from 'web/components/icon/mysettingsicon';
import SessionTimer from 'web/components/sessionTimer/SessionTimer';
import getLogo from 'web/components/structure/getLogo';
import LanguageSwitch from 'web/components/structure/languageswitch';
import useGmp from 'web/hooks/useGmp';
import useTranslation from 'web/hooks/useTranslation';
import useUserIsLoggedIn from 'web/hooks/useUserIsLoggedIn';
import useUserName from 'web/hooks/useUserName';

const Header = () => {
  const [_] = useTranslation();

  const gmp = useGmp();
  const username = useUserName();
  const loggedIn = useUserIsLoggedIn();
  const navigate = useNavigate();
  const logoComponent = getLogo(gmp.settings.vendorLabel);
  const timezone = useSelector(state => state.userSettings.timezone);

  const handleSettingsClick = useCallback(
    event => {
      event.preventDefault();
      navigate('/usersettings');
    },
    [navigate],
  );

  const handleLogout = useCallback(
    event => {
      event.preventDefault();

      gmp.doLogout().then(() => {
        navigate('/login?type=logout');
      });
    },
    [gmp, navigate],
  );

  const menuPoints = [
    {
      to: handleSettingsClick,
      linkText: _('Settings'),
      icon: <MySettingsIcon />,
    },
    {
      to: handleLogout,
      linkText: _('Logout'),
      icon: <LogoutIcon />,
    },
  ];

  return (
    <AppHeader
      ianaTimeZone={timezone}
      isLoggedIn={loggedIn}
      isThemeSwitchVisible={false}
      languageSwitch={<LanguageSwitch />}
      logo={logoComponent}
      logoLink="/dashboards"
      menuPoints={menuPoints}
      sessionTimer={<SessionTimer />}
      username={username}
    />
  );
};

export default Header;
